==> general_tools-0.0.7.crate: general_tools-0.0.7/src/conversions/temperature_conversions.rs <==
// Tipo Especial

pub struct Temperature {
	pub temperature_type: String,
	pub value: f64,
}

impl Temperature {
	pub fn new() -> Temperature{
		Temperature{
			temperature_type: String::from("Celsius"),
			value: 0.0,
		}
	}
	pub fn to_fahrenheit(&self) -> f64 {
		if self.temperature_type == String::from("Fahrenheit") {
			return self.value;
		} 
		else if self.temperature_type == String::from("Celsius") {
			return self.value * 1.8 + 32.0;
		}
		else if self.temperature_type == String::from("Kelvin") {
			return self.value * 1.8 - 459.889;
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value - 459.67;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * 5.45454545455 + 32f64;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 2.25 + 32f64;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_celsius(&self) -> f64 {
		if self.temperature_type == String::from("Fahrenheit") {
			return (self.value - 32.0) / 1.8
		} 
		else if self.temperature_type == String::from("Celsius") {
			return self.value;
		}
		else if self.temperature_type == String::from("Kelvin") {
			return self.value - 273.15;
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value / 1.8 - 273.15;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (100.0 / 33.0);
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 1.25;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_kelvin(&self) -> f64 {
		if self.temperature_type == String::from("Fahrenheit") {
			return (self.value + 459.67) / 1.8;
		} 
		else if self.temperature_type == String::from("Celsius") {
			return self.value + 273.15;
		}
		else if self.temperature_type == String::from("Kelvin") {
			return self.value
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value / 1.8;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (100. / 33.0) + 273.15;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 1.25 + 273.15;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_rankine(&self) -> f64 {
		if self.temperature_type == String::from("Fahrenheit") {
			return self.value + 459.67;
		} 
		else if self.temperature_type == String::from("Celsius") {
			return (self.value + 273.15) * 1.8;
		}
		else if self.temperature_type == String::from("Kelvin") {
			return self.value * 1.8;
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (60.0/11.0) + 491.67;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 2.25 + 491.67;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_newton(&self) -> f64 {
		if self.temperature_type == String::from("Fahrenheit") {
			return (self.value - 32.0) * (60.0 / 11.0);
		} 
		else if self.temperature_type == String::from("Celsius") {
			return self.value * (100.0 / 33.0);
		}
		else if self.temperature_type == String::from("Kelvin") {
			return (self.value - 273.15) * (100.0 / 33.0);
		}
		else if self.temperature_type == String::from("Rankine") {
			return (self.value - 491.67) * (60.0 / 11.0);
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * (33.0 / 80.0);
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_reaumur(&self) -> f64 {
		if self.temperature_type == String::from("Fahrenheit") {
			return (self.value - 32.0) / 2.25;
		}
		else if self.temperature_type == String::from("Celsius") {
			return self.value * 0.8;
		}
		else if self.temperature_type == String::from("Kelvin") {
			return (self.value - 273.15) * 0.8;
		}
		else if self.temperature_type == String::from("Rankine") {
			return (self.value - 491.67) / 2.25;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (33.0 / 80.0);
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
}

==> general_tools-0.0.75.crate: general_tools-0.0.75/src/conversions/temperature_conversions.rs <==
// Tipo Especial

pub struct Temperature {
	pub temperature_type: String,
	pub value: f64,
}

impl Temperature {
	pub fn new() -> Temperature{
		Temperature{
			temperature_type: String::from("Celsius"),
			value: 0.0,
		}
	}
	pub fn to_fahrenheit(&self) -> f64 {
		if self.temperature_type == String::from("Celsius") {
			return self.value * 1.8 + 32.0;
		}
		else if self.temperature_type == String::from("Fahrenheit") {
			return self.value;
		} 
		else if self.temperature_type == String::from("Kelvin") {
			return self.value * 1.8 - 459.889;
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value - 459.67;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * 5.45454545455 + 32f64;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 2.25 + 32f64;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_celsius(&self) -> f64 {
		if self.temperature_type == String::from("Celsius") {
			return self.value;
		}
		else if self.temperature_type == String::from("Fahrenheit") {
			return (self.value - 32.0) / 1.8
		} 
		else if self.temperature_type == String::from("Kelvin") {
			return self.value - 273.15;
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value / 1.8 - 273.15;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (100.0 / 33.0);
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 1.25;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_kelvin(&self) -> f64 {
		if self.temperature_type == String::from("Celsius") {
			return self.value + 273.15;
		}
		else if self.temperature_type == String::from("Fahrenheit") {
			return (self.value + 459.67) / 1.8;
		} 
		else if self.temperature_type == String::from("Kelvin") {
			return self.value
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value / 1.8;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (100. / 33.0) + 273.15;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 1.25 + 273.15;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_rankine(&self) -> f64 {
		if self.temperature_type == String::from("Celsius") {
			return (self.value + 273.15) * 1.8;
		}
		else if self.temperature_type == String::from("Fahrenheit") {
			return self.value + 459.67;
		} 
		else if self.temperature_type == String::from("Kelvin") {
			return self.value * 1.8;
		}
		else if self.temperature_type == String::from("Rankine") {
			return self.value;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (60.0/11.0) + 491.67;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * 2.25 + 491.67;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_newton(&self) -> f64 {
		if self.temperature_type == String::from("Celsius") {
			return self.value * (33.0 / 100.0);
		}
		else if self.temperature_type == String::from("Fahrenheit") {
			return (self.value - 32.0) * (11.0 / 60.0);
		} 
		else if self.temperature_type == String::from("Kelvin") {
			return (self.value - 273.15) * (100.0 / 33.0);
		}
		else if self.temperature_type == String::from("Rankine") {
			return (self.value - 491.67) * (60.0 / 11.0);
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value;
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value * (33.0 / 80.0);
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
	
	pub fn to_reaumur(&self) -> f64 {
		if self.temperature_type == String::from("Celsius") {
			return self.value * 0.8;
		}
		else if self.temperature_type == String::from("Fahrenheit") {
			return (self.value - 32.0) / 2.25;
		}
		else if self.temperature_type == String::from("Kelvin") {
			return (self.value - 273.15) * 0.8;
		}
		else if self.temperature_type == String::from("Rankine") {
			return (self.value - 491.67) / 2.25;
		}
		else if self.temperature_type == String::from("Newton") {
			return self.value * (33.0 / 80.0);
		}
		else if self.temperature_type == String::from("Réaumur") {
			return self.value;
		}
		else {
			panic!("Unsupported temperature type");
		}
	}
}
